ASReview Dory
=============

ASReview Dory is an official extension of ASReview LAB that introduces advanced
models and components for systematic review screening. Dory is a collection of
state-of-the-art tools designed to handle complex datasets and provide more
accurate results. These models are optimized for scalability and performance,
making them ideal for researchers working with large or multilingual datasets.

Installation
------------

Installing ASReview Dory works like any other Python package. Simply install
it using the following command:

.. code:: bash

	pip install asreview-dory

After installation, :ref:`lab/models:ELAS Heavy` and :ref:`lab/models:ELAS Multilingual` are available
for use.  Additionally, under the "Custom" option, you can mix and match various
feature extractors and classifiers to suit your needs.

.. tip::
  Since these models are generally more computationally intensive,
  it may take some time for the feature extractor and classifier to
  process your data.
